==> qt-creator-1.2.0-src.zip: qt-creator-1.2.0-src/src/plugins/qt4projectmanager/wizards/emptyprojectwizarddialog.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#ifndef EMPTYPROJECTWIZARDDIALOG_H
#define EMPTYPROJECTWIZARDDIALOG_H

#include <QtGui/QWizard>

namespace Core {
    namespace Utils {
        class ProjectIntroPage;
    }
}

namespace Qt4ProjectManager {
namespace Internal {

struct QtProjectParameters;

class EmptyProjectWizardDialog : public QWizard
{
    Q_OBJECT

public:
    explicit EmptyProjectWizardDialog(const QString &templateName,
                                    const QIcon &icon,
                                    const QList<QWizardPage*> &extensionPages,
                                    QWidget *parent = 0);

    QtProjectParameters parameters() const;

public slots:
    void setPath(const QString &path);
    void setName(const QString &name);

private:
    Core::Utils::ProjectIntroPage *m_introPage;
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // EMPTYPROJECTWIZARDDIALOG_H

==> qt-creator-2.0.0-rc1-src.zip: qt-creator-2.0.0-rc1-src/src/plugins/qt4projectmanager/wizards/emptyprojectwizarddialog.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef EMPTYPROJECTWIZARDDIALOG_H
#define EMPTYPROJECTWIZARDDIALOG_H

#include "qtwizard.h"

namespace Qt4ProjectManager {
namespace Internal {

struct QtProjectParameters;

class EmptyProjectWizardDialog : public BaseQt4ProjectWizardDialog
{
    Q_OBJECT
public:
    explicit EmptyProjectWizardDialog(const QString &templateName,
                                    const QIcon &icon,
                                    const QList<QWizardPage*> &extensionPages,
                                    QWidget *parent = 0);

    QtProjectParameters parameters() const;
};

} // namespace Internal
} // namespace Qt4ProjectManager

#endif // EMPTYPROJECTWIZARDDIALOG_H
